@@ -1,5 +1,3 @@
-library(bayesnec)
-
 test_that("x must be a named list", {
   expect_error(compare_fitted(list(ecx4param, nec4param)))
   expect_error(compare_fitted(ecx4param, nec4param))
@@ -7,7 +5,7 @@ test_that("x must be a named list", {
 
 test_that("output is a list of appropriately name elements", {
   cf <- compare_fitted(list(ecx4param = ecx4param, nec4param = nec4param),
-                       precision = 10)
+                       resolution = 10)
   expect_equal(class(cf), "list")
   expect_equal(length(cf), 5)
   expect_equal(names(cf), c("posterior_list", "posterior_data", "diff_list",
