@@ -21,8 +21,8 @@ orig_files <- dir(path = "vignettes/", pattern = "*\\.Rmd\\.orig",
 # need to set system variable locally first -------------------------------
 Sys.setenv("NOT_CRAN" = "true")
 purrr::walk(orig_files, ~knitr::knit(.x, file_path_sans_ext(.x)))
-# Move .png files into correct directory so they render -------------------
-images <- dir(".", pattern = "vignette-fig.*\\.png$")
+# Move .pdf files into correct directory so they render -------------------
+images <- dir(".", pattern = "vignette-fig.*\\.pdf$")
 success <- file.copy(from = images, to = file.path("vignettes", images),
                      overwrite = TRUE)
 # Clean up if successful --------------------------------------------------
